@@ -496,8 +496,8 @@ def exec_includes(obj, includes, isbatch=False, _test_=None):
 
 def exec_checkconnection(obj, showResponse=False):
     # 检查测试连接
-    if '_conn_' not in objtarget:
-        create_conn(objtarget)
+    if '_conn_' not in obj:
+        create_conn(obj)
     if hasattr(obj['_conn_'], 'is_connected'): #以此来区分是远程连接还是本地连接，本地连接不会有is_connected属性
         try:
             ret = obj['_conn_'].run('pwd', pty=False, hide=True)
